Struct os_pipe::PipeReader
source · [−]pub struct PipeReader(_);Expand description
The reading end of a pipe, returned by pipe.
PipeReader implements Into<Stdio>, so you can pass it as an argument to
Command::stdin to spawn a child process that reads from the pipe.
Implementations
sourceimpl PipeReader
impl PipeReader
pub fn try_clone(&self) -> Result<PipeReader>